@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997  Dimitrios P. Bouras
+  Copyright (C) 1997,1998  Dimitrios P. Bouras
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,9 @@
 
 /* PPP networking utility routines */
 
+char *IFAddr(char *, int);	/* get IF source or destination address */
 char *pppAddr(char *);		/* if PPP IF active, returns IP address string */
-unsigned pppPkts(char *);	/* returns sum of TX and RX packets on IF */
+unsigned pppPkts(char *,	/* returns sum of TX and RX packets on IF, and */
+	unsigned long*,			/* if storage specified, TX/RX in separate vars */
+	unsigned long *);
 
