@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997  Dimitrios P. Bouras
+  Copyright (C) 1997,1998  Dimitrios P. Bouras
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,9 +20,7 @@
 
 /* ASCII resource control file I/O routines */
 
-void readAllXisprc(char *rcfname, xisprc_t *rcdata);
-void readXisprc(char *rcfname, xisprc_t *rcdata, int rec);
-void writeXisprc(char *rcfname, xisprc_t *rcdata, int rec);
-
-#define writeAllXisprc(name, rec) writeXisprc(name, 1);
+void initXisprc(xisprc_t *p);
+void readXisprc(char *rcfname, xisprc_t **rcdataptr, glob_t *global);
+void writeXisprc(char *rcfname, xisprc_t *rcdata, glob_t *global);
 
