@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997  Dimitrios P. Bouras
+  Copyright (C) 1997,1998  Dimitrios P. Bouras
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,40 +32,50 @@
 #include <signal.h>
 #include "common.h"
 
+#ifdef SUNOS41x
+extern int sys_nerr;
+extern char *sys_errlist[];
+extern int errno;
+extern int fputs(), fscanf(), fprintf(), fclose();
+extern char *vsprintf();
+#endif
+
 /*+-------------------------------------------------------------------------+
   |                                                                         |
   |                         Global program storage                          |
   |                                                                         |
   +-------------------------------------------------------------------------+*/
 
-char *pipefname;							/* named pipe report file */
-int pipeFD = 0;								/* report file descriptor */
-char *scriptfname;							/* login script filename */
-char *envfname;								/* dialing environment filename */
-int childPID;								/* PID of running child */
-
-int maxAttempts = MAXNUM_RETRY;				/* max dialing attempts */
-int sleepDelay = MAXSEC_DELAY;				/* post-dial sleep delay */
-int connectWait = MAXSEC_CNWAIT;			/* maximum wait for connection */
-char account[MAXLEN_ACCOUNT+2];				/* account name */
-char passwd[MAXLEN_PASSWD+2];				/* password */
-char **phone;								/* phone numbers */
-int numPhones;								/* how many there are to dial */
-char **sline;								/* script lines */
-int numSlines;								/* how many there are to include */
-char **CBsln;								/* call-back script lines */
-int numCBSlns;								/* how many there are to include */
-int CBDelay;								/* time wait for call-back */
-char *modemInit;							/* modem init string */				
-char modemUInit[MAXLEN_MODEM+2];			/* user specified modem init str */
-char modemUReset[MAXLEN_MODEM+2];			/* user specified reset string */				
-char dialType;								/* dialing type character */
-int autologin;								/* true for automatic login */
-int callback;								/* true when call-back desired */
-char dispname[MAXLEN_TTPARM+2];				/* X11 display for auto login */
-char winpos[MAXLEN_TTPARM+2];				/* and terminal window position */
-int authlogin;								/* true for PAP/PAPS/CHAPS login */
-char bgcol[16] = {0};						/* form-background color string */
+char *scriptfname;						/* login script filename */
+char *envfname;							/* dialing environment filename */
+char Chat[MAXLEN_FNAME+2];				/* complete path to chat utility */
+char Pipe[MAXLEN_FNAME+2];				/* named pipe report file */
+char Terminal[MAXLEN_FNAME+2];			/* complete path to xispterm */
+int pipeFD = 0;							/* report file descriptor */
+int childPID;							/* PID of running child */
+int maxAttempts = MAXNUM_RETRY;			/* max dialing attempts */
+int sleepDelay = MAXSEC_DELAY;			/* post-dial sleep delay */
+int connectWait = MAXSEC_CNWAIT;		/* maximum wait for connection */
+char account[MAXLEN_ACCOUNT+2];			/* account name */
+char **phone;							/* phone numbers */
+int numPhones;							/* how many there are to dial */
+char **sline;							/* script lines */
+int numSlines;							/* how many there are to include */
+char **CBsln;							/* call-back script lines */
+int numCBSlns;							/* how many there are to include */
+int CBDelay;							/* time wait for call-back */
+char *modemInit;						/* modem init string */				
+char modemUInit[MAXLEN_MDMCMD+2];		/* user specified modem init str */
+char modemUReset[MAXLEN_MDMCMD+2];		/* user specified modem reset string */				
+char modemUConn[MAXLEN_MDMSTR+2];		/* user specified modem connect str */
+char modemDial[MAXLEN_DIALEXTRA+2+2];	/* dialing chars + method char */
+int autologin = 1;						/* true for automatic login */
+int callback = 0;						/* true when call-back desired */
+int manual = 0;							/* true for manual terminal */
+char dispname[MAXLEN_TTPARM+2];			/* X11 display for auto login */
+char geometry[MAXLEN_TTPARM+2];			/* and terminal window geometry */
+int authlogin;							/* true for PAP/PAPS/CHAPS login */
+char bgcol[16] = {0};					/* form-background color string */
 
 
 /*+-------------------------------------------------------------------------+
@@ -83,10 +93,14 @@ void doErr(char *msg)
 {
 	char emsg[MSGLEN_ERR];
 
+#ifndef SUNOS5x
 	if (errno < sys_nerr)
 		sprintf(emsg, "xispdial: %s: %s\n", msg, sys_errlist[errno]);
 	else
 		sprintf(emsg, "xispdial: %s: error #%d\n", msg, errno);
+#else
+	sprintf(emsg, "xispdial: %s: %s\n", msg, strerror(errno));
+#endif
 	fputs(emsg, stderr);
 	if (pipeFD) close(pipeFD);
 	exit(1);
@@ -107,7 +121,11 @@ int namedPipe(char *fname)
 		if (!S_ISFIFO(st.st_mode))				/* is it a FIFO? */
 			doErr("namedPipe: stat");			/* nope, still not right! */
 	}
+#ifndef SUNOS5x
 	fd = open(fname, O_WRONLY|O_NDELAY);		/* yes, open it for writing */
+#else
+	fd = open(fname, O_WRONLY|O_NONBLOCK);		/* yes, open it for writing */
+#endif
 	if (fd < 0)									/* error means no process has */
 		doErr("namedPipe: open");				/* opened it for reading */
 	return fd;									/* return the descriptor */
@@ -127,7 +145,12 @@ int pprintf(va_alist) va_dcl
 
 	va_start(ap);								/* start variable arg list */
 	fmt = va_arg(ap, char*);					/* first string is format */
+#ifndef SUNOS41x
 	iw = vsprintf(msg, fmt, ap);				/* pass rest to vsprintf() */
+#else
+	vsprintf(msg, fmt, ap);
+	iw = strlen(msg);
+#endif
 	va_end(ap);									/* end variable arg list */
 	bw = write(pipeFD, msg, strlen(msg));		/* write buffer to pipe */
 	if (bw < strlen(msg))						/* all bytes written? */
@@ -191,12 +214,9 @@ void initFnames(void)
 	struct passwd *user;
 
 	user = getpwuid(getuid());
-	pipefname = (char *)malloc(6+strlen(user->pw_name)+strlen(PIPEFNAME)+1);
 	scriptfname = (char *)malloc(strlen(user->pw_dir)+1+strlen(SCRIPTFNAME)+1);
 	envfname = (char *)malloc(strlen(user->pw_dir)+1+strlen(ENVFNAME)+1);
-	if (pipefname != NULL && scriptfname != NULL && envfname != NULL) {
-		strcpy(pipefname, "/tmp/"); strcat(pipefname, PIPEFNAME);
-		strcat(pipefname, "."); strcat(pipefname, user->pw_name);
+	if (scriptfname != NULL && envfname != NULL) {
 		strcpy(scriptfname, user->pw_dir); strcat(scriptfname, "/");
 		strcat(scriptfname, SCRIPTFNAME);
 		strcpy(envfname, user->pw_dir); strcat(envfname, "/");
@@ -218,12 +238,42 @@ void uEOF(void)
 
 FILE *envfp;  /* environment file pointer common to readLine(), getISPenv() */
 
-void readLine(char *param, int len)
+/* The readLine function reads a single line from the environment file
+   prepared by xisp and before returning can be instructed to either escape
+   all '\\' characters, or to delete them from the buffer. It assumes that
+   the buffer has the space required for escaping all '\\' characters found. */
+
+void readLine(char *param, int len, int escape)
 {
+	char *p;
+	int zlen;	/* line length (includes ending '\x0') */
+
 	if (fgets(param, len+1,						/* read environment line */
 			  envfp) == NULL)
 		uEOF();									/* bail out on error */
-	param[strlen(param)-1]=0;					/* kill the ending '\n' */
+	param[(zlen = strlen(param))-1]=0;			/* kill the ending '\n' */
+	for (p=param; *p;) {						/* scan the line */
+		if (*p == '\\') {						/* if a '\\' is found */
+			if (escape) {						/* if auto escaping selected */
+#ifndef SUNOS41x
+				memmove(p+1, p, zlen);			/* increase string len by 1 */
+#else											/* by duplicating the string */
+				bcopy(p, p+1, zlen);			/* contents starting from */
+#endif											/* next character position */
+				*p = '\\';						/* insert an extra '\\' */
+				p += 2;							/* skip the next '\\' */
+			}
+			else {								/* deletion of '\\'s desired */
+#ifndef SUNOS41x
+				memmove(p, p+1, zlen);			/* decrease string len by 1 */
+#else
+				bcopy(p+1, p, zlen);
+#endif
+			}
+		}
+		else									/* char not a '\\' */
+			++p;								/* so carry on */
+	}
 }
 
 void getISPenv(void)
@@ -235,8 +285,11 @@ void getISPenv(void)
 	if (envfp == NULL)							/* if not there bail out */
 		doErr("getISPenv: fopen");
 
-	ir = fscanf(envfp,"%d ",&maxAttempts);		/* read all needed dialing */
-	ir += fscanf(envfp,"%d ",&sleepDelay);		/* environment variables */
+	readLine(Chat, MAXLEN_FNAME, 0);			/* read all needed dialing */
+	readLine(Pipe, MAXLEN_FNAME, 0);			/* environment variables */
+	readLine(Terminal, MAXLEN_FNAME, 0);
+	ir = fscanf(envfp,"%d ",&maxAttempts);
+	ir += fscanf(envfp,"%d ",&sleepDelay);
 	ir += fscanf(envfp,"%d ",&connectWait);
 	ir += fscanf(envfp,"%d ",&numPhones);		/* read # of phone numbers */
 	if (ir < 4)									/* all read so far? */
@@ -256,17 +309,23 @@ void getISPenv(void)
 	if (phone == NULL)							/* allocation completed? */
 		outOfMem("getISPenv");					/* nope, bail out */
 	for (i=0; i<numPhones; i++)
-		readLine(phone[i], MAXLEN_PHONE);		/* read telephone numbers */
-	readLine(LM, sizeof(LM)-2);					/* read login method */
-	autologin = (strstr(LM, "AUTO") != NULL);	/* set autologin flag */
+		readLine(phone[i], MAXLEN_PHONE, 0);	/* read telephone numbers */
+	readLine(LM, (sizeof LM)-2, 0);				/* read login method */
+	autologin = (strstr(LM, "AUTO") != NULL);	/* adjust autologin flag */
 	if (autologin)
-		callback = !strcmp(LM, "AUTO-CB");		/* set call-back flag */
-	else
-		authlogin = !strcmp(LM, "AUTH");		/* set authlogin flag */
+		callback = !strcmp(LM, "AUTO-CB");		/* adjust call-back flag */
+	else {
+		authlogin = (strstr(LM, "AUTH")!=NULL);	/* adjust authlogin flag */
+		if (authlogin) {
+			callback = !strcmp(LM, "AUTH-CB");	/* adjust call-back flag */
+			manual = !strcmp(LM, "AUTH-MAN");	/* adjust manual flag */
+		}
+		else
+			manual = 1;
+	}
 
 	if (autologin) {							/* if login is indeed auto */
-		readLine(account, MAXLEN_ACCOUNT);		/* read account name */
-		readLine(passwd, MAXLEN_PASSWD);		/* read password and */
+		readLine(account, MAXLEN_ACCOUNT, 0);	/* read account name and */
 		ir = fscanf(envfp,"%d ",&numSlines);	/* number of script lines */
 		if (! ir)								/* bail out on error */
 			uEOF();
@@ -277,7 +336,8 @@ void getISPenv(void)
 				 i++)
 			{
 				sline[i] = (char *)				/* allocate script line */
-					malloc(2*MAXLEN_SLINE+5+2);
+					malloc(4*MAXLEN_SLINE+10	/* double the size for */
+						  +5*MAXLEN_ACCOUNT+2);	/* automatic escaping */
 				if (sline[i] != NULL)
 					*(sline[i]) = 0;			/* and initialize it */
 				else
@@ -287,7 +347,8 @@ void getISPenv(void)
 				outOfMem("getISPenv");			/* nope, bail out */
 			for (i=0; i<numSlines; i++)
 				readLine(sline[i],				/* read script lines */
-						 2*MAXLEN_SLINE+5);
+						 4*MAXLEN_SLINE+10+
+						 5*MAXLEN_ACCOUNT, 1);
 		}
 		if (callback) {
 			ir= fscanf(envfp,"%d ",&CBDelay);	/* time wait for call-back */
@@ -303,8 +364,8 @@ void getISPenv(void)
 					 i++)
 				{
 					CBsln[i] = (char *)			/* allocate call-back line */
-						malloc(2*MAXLEN_SLINE
-							   +5+2);
+						malloc(4*MAXLEN_SLINE+
+						 10+5*MAXLEN_ACCOUNT+2);
 					if (CBsln[i] != NULL)
 						*(CBsln[i]) = 0;		/* and initialize it */
 					else
@@ -314,20 +375,35 @@ void getISPenv(void)
 					outOfMem("getISPenv");		/* nope, bail out */
 				for (i=0; i<numCBSlns; i++)
 					readLine(CBsln[i],			/* read script lines */
-							 2*MAXLEN_SLINE+5);
+							 4*MAXLEN_SLINE+10+
+							 5*MAXLEN_ACCOUNT, 1);
 			}
 		}
 	}
-	else if (!authlogin) {						/* !authlogin->manual login */
-		readLine(dispname, MAXLEN_TTPARM);		/* read the X11 display */
-		readLine(bgcol, sizeof(bgcol)-2);		/* read background color */
-		readLine(winpos, MAXLEN_TTPARM);		/* read window position */
+	else if (authlogin) {						/* auth-login? */
+		if (callback) {							/* yes, call-back desired? */
+			if (fscanf(envfp,"%d ",&CBDelay)<1)	/* time wait for call-back */
+				uEOF();							/* bail out on error */
+		}
+		else if (manual) {						/* manual terminal desired */
+			readLine(dispname,					/* read the X11 display */
+					 MAXLEN_TTPARM, 0);
+			readLine(bgcol,						/* read background color */
+					 (sizeof bgcol)-2, 0);
+			readLine(geometry,					/* read window geometry */
+					 MAXLEN_TTPARM, 0);
+		}
+	}
+	else {										/* else manual login desired */
+		readLine(dispname, MAXLEN_TTPARM, 0);	/* read the X11 display */
+		readLine(bgcol, (sizeof bgcol)-2, 0);	/* read background color */
+		readLine(geometry, MAXLEN_TTPARM, 0);	/* read window geometry */
 	}
 
-	readLine(modemUReset, MAXLEN_MODEM);		/* modem reset string */
-	readLine(modemUInit, MAXLEN_MODEM);			/* modem init string */
-	if (fscanf(envfp,"%c ",&dialType) < 1)		/* and dialing type */
-		uEOF();									/* bail out on error */
+	readLine(modemUReset, MAXLEN_MDMCMD, 1);	/* modem reset string */
+	readLine(modemUInit, MAXLEN_MDMCMD, 1);		/* modem init string */
+	readLine(modemDial, MAXLEN_DIALEXTRA+2, 0);	/* dial char(s) + method */
+	readLine(modemUConn, MAXLEN_MDMSTR, 0);		/* modem connect string */
 
 	fclose(envfp);								/* close and remove the */
 	unlink(envfname);							/* temp environment file */
@@ -346,36 +422,29 @@ void getISPenv(void)
 #define MODEM_SLEEP 1
 #endif
 
-int init_modem(void)							/* initialize modem */
+int init_modem(char *initCmd)					/* initialize modem */
 {
 	int rcode;
 
-	rcode = child(CHAT,"-V","TIMEOUT","3",
-				  "",modemUReset,"OK-+++\\c-OK",
-				  modemInit,(char *)0);
-	sleep(MODEM_SLEEP);
-	return rcode;
-}
-
-int re_init_modem(void)							/* re-initialize modem */
-{
-	int rcode;
-
-	rcode = child(CHAT,"-V","TIMEOUT","3",
-				  "",modemUReset,"OK-+++\\c-OK",
-				  modemInit,(char *)0);
+	rcode = child(Chat,"-V","TIMEOUT","3",
+				  "", modemUReset, "OK", initCmd,
+				  (char *)0);
 	if (rcode) {
-		sleep(MODEM_SLEEP);
-		rcode = child(CHAT,"-V","TIMEOUT","3",
-					  "","AT","OK-AT-OK",
-					  modemInit,(char *)0);
+		rcode = child(Chat,"-V","TIMEOUT","3",
+					  "", "+++\\c", "OK", modemUReset,
+					  "OK", initCmd, (char *)0);
+		if (rcode)
+			rcode = child(Chat,"-V","TIMEOUT","3",
+						  "","AT","OK-AT-OK",
+						  modemUReset, "OK",
+						  initCmd, (char *)0);
 	}
 	sleep(MODEM_SLEEP);
 	return rcode;
 }
 
-#define MAXLEN_PREAMBLE 256
-#define MAXLEN_CBTRAIL  128
+#define MAXLEN_PREAMBLE 512
+#define MAXLEN_CBTRAIL  256
 
 int callnumber(char *number)					/* dial the number given */
 {
@@ -383,14 +452,15 @@ int callnumber(char *number)					/* dial the number given */
 	FILE *scriptF;
 	char preambleD[MAXLEN_PREAMBLE+1] =
 			"TIMEOUT\t\t3\nABORT\t\tBUSY\nABORT\t\t'NO CARRIER'\n"
-			"ABORT\t\tenied\nABORT\t\timeout\n''\t\t\t'AT D%c %s'\n"
-			"TIMEOUT\t\t%d\nCONNECT\t\t''\nTIMEOUT\t\t5\n\\r\t\t''\n",
+			"ABORT\t\t'NO DIALTONE'\nABORT\t\tenied\nABORT\t\timeout\n"
+			"''\t\t\t'AT %s %s'\nTIMEOUT\t\t%d\n%s\t\t\\c\n"
+			"TIMEOUT\t\t5\n\\r\t\t\\c\n",
 		 preambleCB[MAXLEN_PREAMBLE+1] =
-			"TIMEOUT\t\t3\nABORT\t\tBUSY\n"
-			"ABORT\t\tenied\nABORT\t\timeout\n''\t\t\t'AT D%c %s'\n"
-			"TIMEOUT\t\t%d\nCONNECT\t\t''\nTIMEOUT\t\t5\n\\r\t\t''\n",
+			"TIMEOUT\t\t3\nABORT\t\tBUSY\nABORT 'NO DIALTONE'\n"
+			"ABORT\t\tenied\nABORT\t\timeout\n''\t\t\t'AT %s %s'\n"
+			"TIMEOUT\t\t%d\n%s\t\t\\c\nTIMEOUT\t\t5\n\\r\t\t\\c\n",
 		 cbtrail[MAXLEN_CBTRAIL+1] =
-			"TIMEOUT\t\t%d\nCONNECT\t\t''\nTIMEOUT\t\t5\n\\r\t\t''\n",
+			"TIMEOUT\t\t%d\n%s\t\t\\c\nTIMEOUT\t\t5\n\\r\t\t\\c\n",
 		 script[MAXNUM_SLINES*(2*MAXLEN_SLINE+5)+MAXLEN_PREAMBLE+1];
 
 	umask(077);									/* read/write only by owner */
@@ -406,42 +476,54 @@ int callnumber(char *number)					/* dial the number given */
 			strcat(script, sline[i]);
 			strcat(script, "\n");
 		}
-		fprintf(scriptF, script, dialType,		/* using the script as fmt */
+		fprintf(scriptF, script, modemDial,		/* using the script as fmt */
 				number, connectWait,			/* stick all the rest in */
-				account, passwd);
+				modemUConn);
 		if (callback) {							/* if call-back is desired */
 			strcpy(script, cbtrail);			/* to the script trail add */
 			for (i=0; i<numCBSlns; i++) {		/* the call-back lines */
 				strcat(script, CBsln[i]);
 				strcat(script, "\n");
 			}
-			fprintf(scriptF, script, CBDelay,	/* using script as fmt stick */
-					account, passwd);			/* delay/account/password in */
+			fprintf(scriptF, script,			/* using script as format */
+					CBDelay, modemUConn);		/* stick the rest in */
 		}
 	}
 	else {										/* PAP/PAPS/CHAPS or manual */
-		strcpy(script, preambleD);				/* copy the dialing preamble */
-		fprintf(scriptF, script, dialType,		/* and print the script out */
-				number);
+		if (authlogin && callback) {			/* auth-login and call-back? */
+			strcpy(script, preambleCB);			/* copy the dialing preamble */
+			fprintf(scriptF, script, modemDial,	/* print dial-in script out */
+					number, connectWait,
+					modemUConn);
+			strcpy(script, cbtrail);			/* copy the call-back trail */
+			fprintf(scriptF, script, CBDelay,	/* and print the rest out */
+					modemUConn);
+		}
+		else {									/* auth, auth-manual, manual */
+			strcpy(script, preambleD);			/* copy the dialing preamble */
+			fprintf(scriptF, script, modemDial,	/* and print the script out */
+					number, connectWait,
+					modemUConn);
+		}
 	}
 	fclose(scriptF);							/* close the script file */
-	rcode = child(CHAT,"-V","-f",				/* hand it over to chat */
+	rcode = child(Chat,"-V","-f",				/* hand it over to chat */
 				  scriptfname,(char *)0);
 	unlink(scriptfname);						/* done with script, delete */
 	if (rcode == 0) {							/* chat terminated OK? */
 		pprintf("\n%s: %s %s\n", "xispdial",	/* yes, send "done" message */
 				"done dialing", number);
-		if (!autologin && !authlogin)			/* start manual login window */
-			rcode = child(TERMINAL, "-bgcol",	/* if it is so desired */
+		if (manual && !callback)				/* start manual login window */
+			rcode = child(Terminal, "-bgcol",	/* if it is so desired */
 						bgcol, "-display",
 					  	dispname, "-geometry",
-						winpos, (char *)0);
+						geometry, (char *)0);
 		close(pipeFD);							/* close the report pipe */
 		exit(rcode);							/* and exit */
 	}
 	if (rcode < 0) {							/* nope, chat problem */
-		pprintf("\n%s: %s\n", "callnumber",		/* report it */
-				"chat execution failed");
+		pprintf("\n%s: %s\n", "xispdial",		/* report it */
+				"chat execution failed!");
 		close(pipeFD);							/* and bail out */
 		exit(1);							
 	}
@@ -464,7 +546,7 @@ void callall(int sn)							/* call the list of numbers */
 			pprintf("%s: %s %s\n",
 				"xispdial", "timeout dialing",
 				phone[i]);
-			child(CHAT,"-V",""," ",(char *)0);	/* and hang-up */
+			child(Chat,"-V",""," ",(char *)0);	/* and hang-up */
 		}
 		sleep(sleepDelay);						/* sleep a while */
 	}
@@ -477,16 +559,18 @@ void callall(int sn)							/* call the list of numbers */
   |                                                                         |
   +-------------------------------------------------------------------------+*/
 
-void Term(int signal)
+void Term(int signum)
 {
-	switch (signal) {
+	switch (signum) {
 		case SIGTERM: {							/* SIGTERM signal received */
 			pprintf("\nxispdial: SIGTERM\n");	/* return status via pipe */
 			if (childPID)						/* if a child is in progress */
 				kill(childPID, SIGTERM);		/* send it SIGTERM also */
+			child(Chat,"-V",""," ",(char *)0);	/* try hanging-up */
 			unlink(envfname);					/* delete environment file */
 			unlink(scriptfname);				/* and script file */
-			re_init_modem();					/* reset the modem */
+			sleep(MODEM_SLEEP);					/* wait a sec before */
+			init_modem("\\c");					/* reseting the modem */
 			close(pipeFD);						/* close the report pipe */
 			exit(1);							/* and exit */
 			break;
@@ -501,11 +585,14 @@ int main()
 
 	signal(SIGTERM, Term);			/* register SIGTERM handler */
 	initFnames();					/* assemble file names used */
-	pipeFD = namedPipe(pipefname);	/* initialize named pipe to xISP */
 	getISPenv();					/* get info via dialing environment file */
+	pipeFD = namedPipe(Pipe);		/* initialize named pipe to xISP */
 
 	pprintf("xispdial: PID=%d.\n", getpid());	/* the '.' is important! */
-	pprintf("xispdial: dialing ISP: user: %s\n", account);
+	if (authlogin)
+		pprintf("xispdial: dialing ISP: using PAP/CHAP\n");
+	else
+		pprintf("xispdial: dialing ISP: user: %s\n", account);
 
 /* Prepare the modem init string
    ----------------------------- */
@@ -517,7 +604,7 @@ int main()
 
 /* Initialize the modem for dialing
    -------------------------------- */
-	if ((rcode=init_modem())) {
+	if ((rcode=init_modem(modemInit))) {
 		pprintf("xispdial: chat returned %d!\n", rcode);
 		pprintf("xispdial: modem init failed!\n");
 		return 1;
@@ -528,7 +615,7 @@ int main()
 	for (attempt=0; attempt<maxAttempts; attempt++) {
 		pprintf("\n");
 		callall(attempt);
-		if ((rcode=re_init_modem())) {
+		if ((rcode=init_modem(modemInit))) {
 			pprintf("xispdial: chat returned %d!\n", rcode);
 			pprintf("xispdial: modem re-init failed!\n");
 			return 1;
