@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997  Dimitrios P. Bouras
+  Copyright (C) 1997,1998  Dimitrios P. Bouras
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,3 +41,10 @@ FD_terminal * create_form_terminal(void);
 
 #define MAXBUF_INPUT 256	/* Input buffer size */
 
+typedef struct {			/* the color structure */
+	int r, g, b;
+} color_t;
+
+#define BGCOL_DEFAULT {79, 124, 156}	/* default form-background color */
+#define BGCOL_STRING  "#4F7C9C"
+
